@@ -12,10 +12,12 @@ our @ISA = qw(Exporter DynaLoader);
 our %EXPORT_TAGS = ( 'constants' => [ qw(MAINTAIN_ASPECT_RATIO IGNORE_ASPECT_RATIO) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'constants'} } );
 our @EXPORT = qw();
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 bootstrap Image::Epeg $VERSION;
 
+warn "Image::Epeg is deprecated. The upstream epeg library has known bugs and is no longer maintained. Please do not use this module.\n";
+
 use constant MAINTAIN_ASPECT_RATIO => 1;
 use constant IGNORE_ASPECT_RATIO => 2;
 
@@ -213,6 +215,9 @@ __END__
 
 Image::Epeg - Thumbnail jpegs at lightning speed
 
+B<DEPRECATED>: This module is deprecated and should not be used.
+The upstream epeg library has known bugs and is no longer maintained.
+
 =head1 SYNOPSIS
 
   use Image::Epeg qw(:constants);
